==> relax-3.2.1.src.tar.bz2: relax-3.2.1/test_suite/unit_tests/_lib/_dispersion/__init__.py <==
###############################################################################
#                                                                             #
# Copyright (C) 2013-2014 Edward d'Auvergne                                   #
#                                                                             #
# This file is part of the program relax (http://www.nmr-relax.com).          #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################


__all__ = [
    'test___init__',
    'test_ns_cpmg_2site_expanded'
]

==> relax-4.0.0.src.tar.bz2: relax-4.0.0/test_suite/unit_tests/_lib/_dispersion/__init__.py <==
###############################################################################
#                                                                             #
# Copyright (C) 2013-2014 Edward d'Auvergne                                   #
# Copyright (C) 2013-2014 Troels E. Linnet                                    #
#                                                                             #
# This file is part of the program relax (http://www.nmr-relax.com).          #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################


__all__ = [
    'test___init__',
    'test_b14',
    'test_cr72',
    'test_cr72_full_cluster_one_field',
    'test_cr72_full_cluster_three_fields',
    'test_dpl94',
    'test_it99',
    'test_lm63',
    'test_ns_cpmg_2site_3d',
    'test_ns_cpmg_2site_expanded',
    'test_m61',
    'test_m61b',
    'test_matrix_exponential',
    'test_mmq_cr72',
    'mp05',
    'tap03',
    'tp02',
    'test_tsmfk01'
]
